<?php
/**
 * amfphp for yii
 *
 * @author WindsDeng <windsdeng@gmail.com>
 * @link http://www.dlf5.com/
 * @copyright Copyright &copy; 2012 DLF5.COM
 * @license http://www.yiiframework.com/license/
 * @version $Id$
 * @package modules
 * @since 1.0
 */
class AmfModule extends CWebModule
{
    /**
     * assetsUrl
     * @var type $_assetsUrl
     */
    private $_assetsUrl;
   
    public function init()
	{
		// this method is called when the module is being created
		// you may place code here to customize the module or the application

		// import the module-level models and components
		$this->setImport(array(
			'amf.models.*',
			'amf.components.*',
            'amf.core.amf.app.*',
		));
	}

    /**
     * beforeControllerAction
     * @param type $controller
     * @param type $action
     * @return boolean 
     */
	public function beforeControllerAction($controller, $action)
	{
		if(parent::beforeControllerAction($controller, $action))
		{
			// this method is called before any module controller action is performed
			// you may place customized code here
			return true;
		}
		else
			return false;
	}
    
    /**
	 * @return string the base URL that contains all published asset files of gii.
	 */
	public function getAssetsUrl()
	{
		if($this->_assetsUrl===null)
			$this->_assetsUrl=Yii::app()->getAssetManager()->publish(Yii::getPathOfAlias('amf.assets'));
		return $this->_assetsUrl;
	}

	/**
	 * @param string $value the base URL that contains all published asset files of gii.
	 */
	public function setAssetsUrl($value)
	{
		$this->_assetsUrl=$value;
	}
    
    /**
     * 初始化AmfPHP
     * @param type $setClassPath
     * @param type $setClassMappingsPath 
     */
    public static function initGateway($setClassPath ,$setClassMappingsPath)
    {
        
        $gateway = new Gateway();
        //Set where the services classes are loaded from, *with trailing slash*
        //$servicesPath defined in globals.php
        $gateway->setClassPath($setClassPath);

        //Set where class mappings are loaded from (ie: for VOs)
        //$voPath defined in globals.php
        $gateway->setClassMappingsPath($setClassMappingsPath); 

        //Read above large note for explanation of charset handling
        //The main contributor (Patrick Mineault) is French, 
        //so don't be afraid if he forgot to turn off iconv by default!
        //$gateway->setCharsetHandler("utf8_decode", "ISO-8859-1", "ISO-8859-1");
        $gateway->setCharsetHandler("iconv", "UTF-8", "UTF-8");

        //Error types that will be rooted to the NetConnection debugger
        $gateway->setErrorHandling(E_ALL ^ E_NOTICE);

        if(!YII_DEBUG)
        {
            //Disable profiling, remote tracing, and service browser
            $gateway->disableDebug();
            // Keep the Flash/Flex IDE player from connecting to the gateway. Used for security to stop remote connections. 
            $gateway->disableStandalonePlayer();
        }
        
        //If you are running into low-level issues with corrupt messages and 
        //the like, you can add $gateway->logIncomingMessages('path/to/incoming/messages/');
        //and $gateway->logOutgoingMessages('path/to/outgoing/messages/'); here
        //$gateway->logIncomingMessages('in/');
        //$gateway->logOutgoingMessages('out/');

        //Explicitly disable the native extension if it is installed
        //$gateway->disableNativeExtension();

        //Enable gzip compression of output if zlib is available, 
        //beyond a certain byte size threshold
        $gateway->enableGzipCompression(25*1024);

        //Service now
        $gateway->service();
    }
}
